@@ -18,6 +18,144 @@ import warnings
 from tencentcloud.common.abstract_model import AbstractModel
 
 
+class ChangeClothesRequest(AbstractModel):
+    """ChangeClothes请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _ModelUrl: 模特图片 Url。
+图片限制：单边分辨率小于3000，且大于512，转成 Base64 字符串后小于 8MB。
+输入要求：
+1、建议上传正面模特图片，至少完整露出应穿着输入指定服装的身体部位（全身、上半身或下半身），无大角度身体偏转或异常姿势。
+2、建议上传3:4比例的图片，生成效果更佳。
+3、建议模特图片中的原始服装和更换后的服装类别一致，或原始服装在身体上的覆盖范围小于等于更换后的服装（例如需要给模特换上短裤，则原始模特图片中也建议穿短裤，不建议穿长裤），否则会影响人像生成效果。
+
+        :type ModelUrl: str
+        :param _ClothesUrl: 服装图片 Url。
+图片限制：单边分辨率小于3000，大于512，转成 Base64 字符串后小于 8MB。
+输入要求：
+建议上传服装完整的正面平铺图片，仅包含1个服装主体，服装类型支持上衣、下装、连衣裙，三选一。算法将根据输入的图片，结合服装图片给模特换装。
+        :type ClothesUrl: str
+        :param _ClothesType: 服装类型，需要和服装图片保持一致。
+取值：
+Upper-body：上衣
+Lower-body：下装
+Dress：连衣裙
+        :type ClothesType: str
+        :param _LogoAdd: 为生成结果图添加标识的开关，默认为1。
+1：添加标识。
+0：不添加标识。
+其他数值：默认按1处理。
+建议您使用显著标识来提示结果图使用了 AI 绘画技术，是 AI 生成的图片。
+        :type LogoAdd: int
+        :param _RspImgType: 返回图像方式（base64 或 url) ，二选一，默认为 base64。url 有效期为1小时。
+生成图分辨率较大时建议选择 url，使用 base64 可能因图片过大导致返回失败。
+        :type RspImgType: str
+        """
+        self._ModelUrl = None
+        self._ClothesUrl = None
+        self._ClothesType = None
+        self._LogoAdd = None
+        self._RspImgType = None
+
+    @property
+    def ModelUrl(self):
+        return self._ModelUrl
+
+    @ModelUrl.setter
+    def ModelUrl(self, ModelUrl):
+        self._ModelUrl = ModelUrl
+
+    @property
+    def ClothesUrl(self):
+        return self._ClothesUrl
+
+    @ClothesUrl.setter
+    def ClothesUrl(self, ClothesUrl):
+        self._ClothesUrl = ClothesUrl
+
+    @property
+    def ClothesType(self):
+        return self._ClothesType
+
+    @ClothesType.setter
+    def ClothesType(self, ClothesType):
+        self._ClothesType = ClothesType
+
+    @property
+    def LogoAdd(self):
+        return self._LogoAdd
+
+    @LogoAdd.setter
+    def LogoAdd(self, LogoAdd):
+        self._LogoAdd = LogoAdd
+
+    @property
+    def RspImgType(self):
+        return self._RspImgType
+
+    @RspImgType.setter
+    def RspImgType(self, RspImgType):
+        self._RspImgType = RspImgType
+
+
+    def _deserialize(self, params):
+        self._ModelUrl = params.get("ModelUrl")
+        self._ClothesUrl = params.get("ClothesUrl")
+        self._ClothesType = params.get("ClothesType")
+        self._LogoAdd = params.get("LogoAdd")
+        self._RspImgType = params.get("RspImgType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ChangeClothesResponse(AbstractModel):
+    """ChangeClothes返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _ResultImage: 根据入参 RspImgType 填入不同，返回不同的内容。
+如果传入 base64 则返回生成图 Base64 编码。
+如果传入 url 则返回的生成图 URL , 有效期1小时，请及时保存。
+        :type ResultImage: str
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self._ResultImage = None
+        self._RequestId = None
+
+    @property
+    def ResultImage(self):
+        return self._ResultImage
+
+    @ResultImage.setter
+    def ResultImage(self, ResultImage):
+        self._ResultImage = ResultImage
+
+    @property
+    def RequestId(self):
+        return self._RequestId
+
+    @RequestId.setter
+    def RequestId(self, RequestId):
+        self._RequestId = RequestId
+
+
+    def _deserialize(self, params):
+        self._ResultImage = params.get("ResultImage")
+        self._RequestId = params.get("RequestId")
+
+
 class Filter(AbstractModel):
     """训练图像质量过滤开关配置。
     支持开启或关闭对训练图像分辨率下限、脸部区域大小、脸部遮挡、脸部角度的过滤，默认开启以上过滤。
@@ -88,6 +226,169 @@ class Filter(AbstractModel):
         
 
 
+class GenerateAvatarRequest(AbstractModel):
+    """GenerateAvatar请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _Style: 头像风格。
+请在  [百变头像风格列表](https://cloud.tencent.com/document/product/1668/107741) 中选择期望的风格，必须传入风格编号。
+        :type Style: str
+        :param _InputImage: 输入图 Base64 数据。
+算法将根据输入的图片，结合文本描述智能生成与之相关的图像。
+Base64 和 Url 必须提供一个，如果都提供以 Url 为准。
+图片限制：单边分辨率小于5000，转成 Base64 字符串后小于 6MB，格式支持 jpg、jpeg、png、bmp、tiff、webp。
+        :type InputImage: str
+        :param _InputUrl: 输入图 Url。
+算法将根据输入的图片，结合文本描述智能生成与之相关的图像。
+Base64 和 Url 必须提供一个，如果都提供以 Url 为准。
+图片限制：单边分辨率小于5000，转成 Base64 字符串后小于 6MB，格式支持 jpg、jpeg、png、bmp、tiff、webp。
+        :type InputUrl: str
+        :param _Filter: 输入图像质量检测开关，默认开启。
+1：开启
+0：关闭
+建议开启检测，可提升生成效果，关闭检测可能因输入图像质量较差导致生成效果受损。
+开启后，将增强对输入图像的质量要求，如果输入图像单边分辨率<500、图像中人脸占比较小、存在多人、没有检测到人脸、人脸不完整、人脸遮挡等，将被拦截。
+关闭后，将降低对输入图像的质量要求，如果图像中没有检测到人脸或人脸占比过小等，将被拦截。
+        :type Filter: int
+        :param _LogoAdd: 为生成结果图添加标识的开关，默认为1。
+1：添加标识。
+0：不添加标识。
+其他数值：默认按1处理。
+建议您使用显著标识来提示结果图是 AI 生成的图片。
+        :type LogoAdd: int
+        :param _LogoParam: 标识内容设置。
+默认在生成结果图右下角添加“图片由 AI 生成”字样，您可根据自身需要替换为其他的标识图片。
+        :type LogoParam: :class:`tencentcloud.aiart.v20221229.models.LogoParam`
+        :param _RspImgType: 返回图像方式（base64 或 url) ，二选一，默认为 base64。url 有效期为1小时。
+        :type RspImgType: str
+        """
+        self._Style = None
+        self._InputImage = None
+        self._InputUrl = None
+        self._Filter = None
+        self._LogoAdd = None
+        self._LogoParam = None
+        self._RspImgType = None
+
+    @property
+    def Style(self):
+        return self._Style
+
+    @Style.setter
+    def Style(self, Style):
+        self._Style = Style
+
+    @property
+    def InputImage(self):
+        return self._InputImage
+
+    @InputImage.setter
+    def InputImage(self, InputImage):
+        self._InputImage = InputImage
+
+    @property
+    def InputUrl(self):
+        return self._InputUrl
+
+    @InputUrl.setter
+    def InputUrl(self, InputUrl):
+        self._InputUrl = InputUrl
+
+    @property
+    def Filter(self):
+        return self._Filter
+
+    @Filter.setter
+    def Filter(self, Filter):
+        self._Filter = Filter
+
+    @property
+    def LogoAdd(self):
+        return self._LogoAdd
+
+    @LogoAdd.setter
+    def LogoAdd(self, LogoAdd):
+        self._LogoAdd = LogoAdd
+
+    @property
+    def LogoParam(self):
+        return self._LogoParam
+
+    @LogoParam.setter
+    def LogoParam(self, LogoParam):
+        self._LogoParam = LogoParam
+
+    @property
+    def RspImgType(self):
+        return self._RspImgType
+
+    @RspImgType.setter
+    def RspImgType(self, RspImgType):
+        self._RspImgType = RspImgType
+
+
+    def _deserialize(self, params):
+        self._Style = params.get("Style")
+        self._InputImage = params.get("InputImage")
+        self._InputUrl = params.get("InputUrl")
+        self._Filter = params.get("Filter")
+        self._LogoAdd = params.get("LogoAdd")
+        if params.get("LogoParam") is not None:
+            self._LogoParam = LogoParam()
+            self._LogoParam._deserialize(params.get("LogoParam"))
+        self._RspImgType = params.get("RspImgType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class GenerateAvatarResponse(AbstractModel):
+    """GenerateAvatar返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _ResultImage: 根据入参 RspImgType 填入不同，返回不同的内容。
+如果传入 base64 则返回生成图 Base64 编码。
+如果传入 url 则返回的生成图 URL , 有效期1小时，请及时保存。
+        :type ResultImage: str
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self._ResultImage = None
+        self._RequestId = None
+
+    @property
+    def ResultImage(self):
+        return self._ResultImage
+
+    @ResultImage.setter
+    def ResultImage(self, ResultImage):
+        self._ResultImage = ResultImage
+
+    @property
+    def RequestId(self):
+        return self._RequestId
+
+    @RequestId.setter
+    def RequestId(self, RequestId):
+        self._RequestId = RequestId
+
+
+    def _deserialize(self, params):
+        self._ResultImage = params.get("ResultImage")
+        self._RequestId = params.get("RequestId")
+
+
 class ImageToImageRequest(AbstractModel):
     """ImageToImage请求参数结构体
 
@@ -97,13 +398,13 @@ class ImageToImageRequest(AbstractModel):
         r"""
         :param _InputImage: 输入图 Base64 数据。
 算法将根据输入的图片，结合文本描述智能生成与之相关的图像。
-Base64 和 Url 必须提供一个，如果都提供以 Base64 为准。
-图片限制：单边分辨率小于5000，转成 Base64 字符串后小于 8MB。
+Base64 和 Url 必须提供一个，如果都提供以 Url 为准。
+图片限制：单边分辨率小于5000且大于50，转成 Base64 字符串后小于 8MB，格式支持 jpg、jpeg、png、bmp、tiff、webp。
         :type InputImage: str
         :param _InputUrl: 输入图 Url。
 算法将根据输入的图片，结合文本描述智能生成与之相关的图像。
-Base64 和 Url 必须提供一个，如果都提供以 Base64 为准。
-图片限制：单边分辨率小于5000，转成 Base64 字符串后小于8MB。
+Base64 和 Url 必须提供一个，如果都提供以 Url 为准。
+图片限制：单边分辨率小于5000且大于50，转成 Base64 字符串后小于 8MB，格式支持 jpg、jpeg、png、bmp、tiff、webp。
         :type InputUrl: str
         :param _Prompt: 文本描述。
 用于在输入图的基础上引导生成图效果，增加生成结果中出现描述内容的可能。
@@ -114,7 +415,7 @@ Base64 和 Url 必须提供一个，如果都提供以 Base64 为准。
 推荐使用中文。最多可传256个 utf-8 字符。
         :type NegativePrompt: str
         :param _Styles: 绘画风格。
-请在  [智能图生图风格列表](https://cloud.tencent.com/document/product/1668/86250) 中选择期望的风格，传入风格编号。
+请在  [图像风格化风格列表](https://cloud.tencent.com/document/product/1668/86250) 中选择期望的风格，传入风格编号。
 推荐使用且只使用一种风格。不传默认使用201（日系动漫风格）。
         :type Styles: list of str
         :param _ResultConfig: 生成图结果的配置，包括输出图片分辨率和尺寸等。
@@ -131,7 +432,7 @@ Base64 和 Url 必须提供一个，如果都提供以 Base64 为准。
 默认在生成结果图右下角添加“图片由 AI 生成”字样，您可根据自身需要替换为其他的标识图片。
         :type LogoParam: :class:`tencentcloud.aiart.v20221229.models.LogoParam`
         :param _Strength: 生成自由度。
-Strength 值越小，生成图和原图越接近，取值范围0 - 1，不传使用模型内置的默认值。
+Strength 值越小，生成图和原图越接近，取值范围(0, 1]，不传使用模型内置的默认值。
 推荐的取值范围为0.6 - 0.8。
         :type Strength: float
         :param _RspImgType: 返回图像方式（base64 或 url) ，二选一，默认为 base64。url 有效期为1小时。
@@ -300,11 +601,11 @@ class LogoParam(AbstractModel):
 
     def __init__(self):
         r"""
-        :param _LogoUrl: 水印url
+        :param _LogoUrl: 水印 Url
         :type LogoUrl: str
-        :param _LogoImage: 水印base64，url和base64二选一传入
+        :param _LogoImage: 水印 Base64，Url 和 Base64 二选一传入，如果都提供以 Url 为准
         :type LogoImage: str
-        :param _LogoRect: 水印图片位于融合结果图中的坐标，将按照坐标对标识图片进行位置和大小的拉伸匹配
+        :param _LogoRect: 水印图片位于生成结果图中的坐标，将按照坐标对标识图片进行位置和大小的拉伸匹配
         :type LogoRect: :class:`tencentcloud.aiart.v20221229.models.LogoRect`
         """
         self._LogoUrl = None
@@ -809,6 +1110,177 @@ INIT: 初始化、WAIT：等待中、RUN：运行中、FAIL：处理失败、DON
         self._RequestId = params.get("RequestId")
 
 
+class ReplaceBackgroundRequest(AbstractModel):
+    """ReplaceBackground请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _ProductUrl: 商品原图 Url。
+图片限制：单边分辨率小于4000，长宽比在2:5 ~ 5:2之间，转成 Base64 字符串后小于 6MB，格式支持 jpg、jpeg、png、bmp、tiff、webp。
+        :type ProductUrl: str
+        :param _Prompt: 对新背景的文本描述。
+最多支持256个 utf-8 字符，支持中、英文。
+        :type Prompt: str
+        :param _MaskUrl: 商品 Mask 图 Url，要求背景透明，保留商品主体。
+如果不传，将自动使用内置的商品分割算法得到 Mask。
+支持自定义上传 Mask，如果该参数不为空，则以实际上传的数据为准。
+图片限制：Mask 图必须和商品原图分辨率一致，转成 Base64 字符串后小于 6MB，格式仅支持 png。
+        :type MaskUrl: str
+        :param _Resolution: 替换背景后生成的商品图分辨率。
+支持生成单边分辨率大于500且小于4000、长宽比在2:5 ~ 5:2之间的图片，不传默认生成1280:1280。
+建议图片比例为1:1、9:16、16:9，生成效果更佳，使用其他比例的生成效果可能不如建议比例。
+        :type Resolution: str
+        :param _LogoAdd: 为生成结果图添加标识的开关，默认为1。
+1：添加标识。
+0：不添加标识。
+其他数值：默认按1处理。
+建议您使用显著标识来提示结果图是 AI 生成的图片。
+        :type LogoAdd: int
+        :param _LogoParam: 标识内容设置。
+默认在生成结果图右下角添加“图片由 AI 生成”字样，您可根据自身需要替换为其他的标识图片。
+        :type LogoParam: :class:`tencentcloud.aiart.v20221229.models.LogoParam`
+        :param _RspImgType: 返回图像方式（base64 或 url) ，二选一，默认为 base64。url 有效期为1小时。
+生成图分辨率较大时建议选择 url，使用 base64 可能因图片过大导致返回失败。
+        :type RspImgType: str
+        """
+        self._ProductUrl = None
+        self._Prompt = None
+        self._MaskUrl = None
+        self._Resolution = None
+        self._LogoAdd = None
+        self._LogoParam = None
+        self._RspImgType = None
+
+    @property
+    def ProductUrl(self):
+        return self._ProductUrl
+
+    @ProductUrl.setter
+    def ProductUrl(self, ProductUrl):
+        self._ProductUrl = ProductUrl
+
+    @property
+    def Prompt(self):
+        return self._Prompt
+
+    @Prompt.setter
+    def Prompt(self, Prompt):
+        self._Prompt = Prompt
+
+    @property
+    def MaskUrl(self):
+        return self._MaskUrl
+
+    @MaskUrl.setter
+    def MaskUrl(self, MaskUrl):
+        self._MaskUrl = MaskUrl
+
+    @property
+    def Resolution(self):
+        return self._Resolution
+
+    @Resolution.setter
+    def Resolution(self, Resolution):
+        self._Resolution = Resolution
+
+    @property
+    def LogoAdd(self):
+        return self._LogoAdd
+
+    @LogoAdd.setter
+    def LogoAdd(self, LogoAdd):
+        self._LogoAdd = LogoAdd
+
+    @property
+    def LogoParam(self):
+        return self._LogoParam
+
+    @LogoParam.setter
+    def LogoParam(self, LogoParam):
+        self._LogoParam = LogoParam
+
+    @property
+    def RspImgType(self):
+        return self._RspImgType
+
+    @RspImgType.setter
+    def RspImgType(self, RspImgType):
+        self._RspImgType = RspImgType
+
+
+    def _deserialize(self, params):
+        self._ProductUrl = params.get("ProductUrl")
+        self._Prompt = params.get("Prompt")
+        self._MaskUrl = params.get("MaskUrl")
+        self._Resolution = params.get("Resolution")
+        self._LogoAdd = params.get("LogoAdd")
+        if params.get("LogoParam") is not None:
+            self._LogoParam = LogoParam()
+            self._LogoParam._deserialize(params.get("LogoParam"))
+        self._RspImgType = params.get("RspImgType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            property_name = name[1:]
+            if property_name in memeber_set:
+                memeber_set.remove(property_name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class ReplaceBackgroundResponse(AbstractModel):
+    """ReplaceBackground返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param _ResultImage: 根据入参 RspImgType 填入不同，返回不同的内容。
+如果传入 base64 则返回生成图 Base64 编码。
+如果传入 url 则返回的生成图 URL , 有效期1小时，请及时保存。
+        :type ResultImage: str
+        :param _MaskImage: 如果 MaskUrl 未传，则返回使用内置商品分割算法得到的 Mask 结果。
+        :type MaskImage: str
+        :param _RequestId: 唯一请求 ID，由服务端生成，每次请求都会返回（若请求因其他原因未能抵达服务端，则该次请求不会获得 RequestId）。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self._ResultImage = None
+        self._MaskImage = None
+        self._RequestId = None
+
+    @property
+    def ResultImage(self):
+        return self._ResultImage
+
+    @ResultImage.setter
+    def ResultImage(self, ResultImage):
+        self._ResultImage = ResultImage
+
+    @property
+    def MaskImage(self):
+        return self._MaskImage
+
+    @MaskImage.setter
+    def MaskImage(self, MaskImage):
+        self._MaskImage = MaskImage
+
+    @property
+    def RequestId(self):
+        return self._RequestId
+
+    @RequestId.setter
+    def RequestId(self, RequestId):
+        self._RequestId = RequestId
+
+
+    def _deserialize(self, params):
+        self._ResultImage = params.get("ResultImage")
+        self._MaskImage = params.get("MaskImage")
+        self._RequestId = params.get("RequestId")
+
+
 class ResultConfig(AbstractModel):
     """返回结果配置
 
@@ -818,9 +1290,7 @@ class ResultConfig(AbstractModel):
         r"""
         :param _Resolution: 生成图分辨率
 
-智能文生图支持生成以下分辨率的图片：768:768（1:1）、768:1024（3:4）、1024:768（4:3）、1024:1024（1:1）、720:1280（9:16）、1280:720（16:9）、768:1280（3:5）、1280:768（5:3）、1080:1920（9:16）、1920:1080（16:9），不传默认使用768:768。
-
-智能图生图支持生成以下分辨率的图片：origin（与输入图分辨率一致，长边最高为2000，超出将做等比例缩小）、768:768（1:1）、768:1024（3:4）、1024:768（4:3），不传默认使用origin，如果指定生成的长宽比与输入图长宽比差异过大可能导致图片内容被裁剪。
+图像风格化（图生图）支持生成以下分辨率的图片：origin（与输入图分辨率一致，长边最高为2000，超出将做等比例缩小）、768:768（1:1）、768:1024（3:4）、1024:768（4:3），不传默认使用origin，如果指定生成的长宽比与输入图长宽比差异过大可能导致图片内容被裁剪。
         :type Resolution: str
         """
         self._Resolution = None
@@ -856,45 +1326,8 @@ class SubmitDrawPortraitJobRequest(AbstractModel):
         :param _ModelId: 写真模型 ID。
 
         :type ModelId: str
-        :param _StyleId: 写真风格模板，支持以下风格：
-zhengjian_female：证件照-长发（女）
-zhengjian_shouthair_female：证件照-短发（女）
-zhengjian_male：证件照（男）
-grey_suit_male：灰色西装（男）
-beige_suit_male：米色西装（男）
-white_sweater_male：白色毛衣（男）
-hanfu_female：汉服（女）
-hanfu2_female：汉服2（女）
-green_female：绿色毛衣（女）
-white_sweater_female：白色毛衣（女）
-sports_female：蓝色运动装（女）
-bow_female：蝴蝶结发饰（女）
-wreath_female：头戴花环（女）
-black_dress1_female：小黑裙1（女）
-black_dress2_female：小黑裙2（女）
-black_dress3_female：小黑裙3（女）
-wedding_female：婚纱裙（女）
-wedding2_female：婚纱裙2（女）
-forest_female：树林（女）
-flower_female：花丛（女）
-qipao_female：旗袍（女）
-feather_female：羽毛（女）
-lolita_female：洛丽塔（女）
-blue_shirt_female：蓝衬衣（女）
-green_shirt_female：绿衬衣（女）
-purple_shirt_female：紫衬衣（女）
-fire_female：火焰（女）
-christmas1_female: 圣诞1（女）
-christmas2_female: 圣诞2（女）
-christmas3_female: 圣诞3（适用女性）
-newyear1_female：新春1（女）
-newyear2_female：新春2（女）
-newyear3_female：新春3（女）
-newyear5_female：新春5（女）
-elderly_female：中老年（女）
-elderly_male：中老年（男）
-labour_female：田野劳作（女）
-simple：简洁风格（通用），一般用于写真模型的封面示意图，每个 ModelId 的生成结果固定，多次生成将返回相同图片
+        :param _StyleId: 写真风格模板。
+请在[ AI 写真风格列表](https://cloud.tencent.com/document/product/1668/105740) 中选择期望的风格，传入风格编号。
         :type StyleId: str
         :param _ImageNum: 本次生成的图片数量，取值范围[1,4]
         :type ImageNum: int
@@ -1054,8 +1487,9 @@ class SubmitTextToImageProJobRequest(AbstractModel):
 建议您使用显著标识来提示结果图使用了 AI 绘画技术，是 AI 生成的图片。
         :type LogoAdd: int
         :param _Engine: 文生图模型，默认使用engine1。
-engine1：文生图（高级版）-混元
-engine2：文生图（高级版）
+取值：
+engine1
+engine2
         :type Engine: str
         :param _Revise: prompt 扩写开关。1为开启，0为关闭，不传默认开启。
 开启扩写后，将自动扩写原始输入的 prompt 并使用扩写后的 prompt 生成图片，返回生成图片结果时将一并返回扩写后的 prompt 文本。
